@@ -149,7 +149,7 @@ class CustomFormatter(logging.Formatter):
     def formatException(self, ei) -> str:
         output = super().formatException(ei)
         # return '<br>'.join(line.strip() for line in output.splitlines() if line.strip() != '')
-        repr(output)
+        return repr(output)
 
 
 class ExcludeProfilingStreamHandler(logging.StreamHandler):
